/*****************************************************************************
 *                                                                           *
 *        **********                                                         *
 *       ************                                                        *
 *      ***        ***                                                       *
 *      ***   +++   ***                                                      *
 *      ***   + +   ***                                                      *
 *      ***   +                            CHIPCON CC1010                    *
 *      ***   + +   ***                   MEDIA LAB DAUGHTERCARD             *
 *      ***   +++   ***               HARDWARE DEFINITION FILE               *
 *      ***       ***                                                        *
 *       ***********                                                         *
 *        *********                                                          *
 *                                                                           *
 *****************************************************************************
 * The CC1010EB Evaluation Board has a number of buttons and LEDS which can  *
 * be accessed more easily using the macros in this files.                   *
 *****************************************************************************
 * Author:              Mat Laibowitz based on ROH                           *
 *****************************************************************************/

#ifndef CC1010DC_H
#define CC1010DC_H

#include <reg1010.h>    	// Include register definitions

//********** Constants ************
#define CC1010DC_CLKFREQ 14746

//********** LED macros ***********
#define RLED P3_5
#define GLED P1_2
#define BLED P3_4
#define WLED P1_3

#define LED_ON 	0
#define LED_OFF 1

// LED pin output enable macros
#define RLED_OE(x) {P3DIR=(x) ? P3DIR&~0x20 : P3DIR|0x20;}
#define GLED_OE(x) {P1DIR=(x) ? P1DIR&~0x04 : P1DIR|0x04;}
#define BLED_OE(x) {P3DIR=(x) ? P3DIR&~0x10 : P3DIR|0x10;}
#define WLED_OE(x) {P1DIR=(x) ? P1DIR&~0x08 : P1DIR|0x08;}

//********** Switch macros ***********
#define SW1_PRESSED (!P1_4)
#define SW2_PRESSED (!P2_2)
#define SW3_PRESSED (!P2_3)
#define SW4_PRESSED (!P2_4)
#define SW5_PRESSED (!P2_5)


//********** Misc macros ************
#define DCLK            P0_2
#define DIO             P0_1
#define DCLKIO_OE(b)    {P0DIR=(P0DIR&~0x06)|((b)?0x00:0x06);}


#endif //CC1010DC_H
